#include "main.h"
#include "handlers.h"

static GtkWidget *mainwin;

GladeXML *glade;
xmlDocPtr doc;
xmlNodePtr root;

void obconf_error(gchar *msg)
{
    GtkWidget *d;

    d = gtk_message_dialog_new(mainwin ? GTK_WINDOW(mainwin) : NULL,
                               GTK_DIALOG_DESTROY_WITH_PARENT,
                               GTK_MESSAGE_ERROR,
                               GTK_BUTTONS_CLOSE,
                               "%s", msg);
    g_signal_connect_swapped(GTK_OBJECT(d), "response",
                             G_CALLBACK(gtk_widget_destroy),
                             GTK_OBJECT(d));
    gtk_widget_show(d);
}

int main(int argc, char **argv)
{
    gchar *p;

    gtk_init(&argc, &argv);

    p = g_build_filename(GLADEDIR, "obconf.glade", NULL);
    glade = glade_xml_new(p, NULL, NULL);
    g_free(p);

    if (!glade) {
        obconf_error("Failed to load the obconf.glade interface file. You "
                     "have probably failed to install ObConf properly.");
        return 1;
    }

    xmlIndentTreeOutput = 1;
    if (!parse_load_rc(&doc, &root)) {
        obconf_error("Failed to load an rc.xml. You have probably failed to "
                     "install Openbox properly.");
        return 1;
    }

    glade_xml_signal_autoconnect(glade);

    {
        gchar *s = g_strdup_printf("ObConf %s", PACKAGE_VERSION);
        gtk_label_set_text(GTK_LABEL
                           (glade_xml_get_widget(glade, "title_label")), s);
        g_free(s);
    }

    setup_focus_mouse(glade_xml_get_widget(glade, "focus_mouse"));
    setup_focus_delay(glade_xml_get_widget(glade, "focus_delay"));
    setup_focus_new(glade_xml_get_widget(glade, "focus_new"));
    setup_resist_window_strength(glade_xml_get_widget
                                 (glade, "resist_window_strength"));
    setup_resist_edge_strength(glade_xml_get_widget
                               (glade, "resist_edge_strength"));
    setup_resize_contents(glade_xml_get_widget(glade, "resize_contents"));
    setup_dock_position(glade_xml_get_widget(glade, "dock_position"));
    setup_dock_float_x(glade_xml_get_widget(glade, "dock_float_x"));
    setup_dock_float_y(glade_xml_get_widget(glade, "dock_float_y"));
    setup_dock_stacking(glade_xml_get_widget(glade, "dock_stacking"));
    setup_dock_direction(glade_xml_get_widget(glade, "dock_direction"));
    setup_dock_hide(glade_xml_get_widget(glade, "dock_hide"));
    setup_dock_hide_delay(glade_xml_get_widget(glade, "dock_hide_delay"));
    setup_theme_name(glade_xml_get_widget(glade, "theme_name"));
    setup_theme_layout(glade_xml_get_widget(glade, "theme_layout"));
    setup_desktop_num(glade_xml_get_widget(glade, "desktop_num"));
    setup_desktop_names(glade_xml_get_widget(glade, "desktop_names"));

    mainwin = glade_xml_get_widget(glade, "main_window");

    gtk_widget_show_all(mainwin);

    gtk_main();

    xmlFreeDoc(doc);
    return 0;
}
